==> plugin-codeblock-vue-2.8.76-dev.tgz: package/src/component/select1.ts <==
import {
	$,
	EditorInterface,
	isEngine,
	isHotkey,
	isMobile,
	NodeInterface,
} from '@ctoweb/engine';

type codeblockSelectOptions = {
	modeDatas: Array<{ value: string; syntax: string; name: string }>;
	defaultValue: string;
	onSelect?: (value: string) => void;
};
class codeblockSelect {
	content?: NodeInterface;
	options: codeblockSelectOptions;

	constructor(options: codeblockSelectOptions) {
		this.options = options;
	}
	render() {
		const { modeDatas, defaultValue, onSelect } = this.options;
		this.content = $(`<div class="select-box">
        <div class="select-box-input" style="display:none" > <input type="text"  placeholder="${defaultValue}"></div>
        <div class="select-box-text">${defaultValue}</div>
        <div class="options-box" style="display:none">
             ${this.renderOptions(modeDatas, defaultValue)}
        </div>
    </div>`);
		this.content.find('input').on('input', (e: KeyboardEvent) => {
			if (!e.target) return;
			let value = (e.target as HTMLInputElement).value.toLowerCase();

			if (value) {
				let newModeDatas = modeDatas.filter((e) => {
					return e.value.indexOf(value) > -1;
				});
				this.content
					?.find('.options-box')
					.html(this.renderOptions(newModeDatas, defaultValue));
			}
		});
		this.content.find('input').on('focus', (e: KeyboardEvent) => {
			if (!e.target) return;
			this.content?.find('.options-box').show();
		});
		this.content.find('input').on('blur', (e: KeyboardEvent) => {
			if (!e.target) return;
			setTimeout(() => {
				this.content?.find('.options-box').hide();
			}, 200);
		});
		this.content.find('.select-box-text').on('click', (e: MouseEvent) => {
			if (!e.target || !$(e.target).hasClass('select-box-text')) return;
			$(e.target).hide();
			if (this.content?.find('input').length) {
				this.content?.find('.select-box-input').show();
				(this.content?.find('input')[0] as HTMLInputElement).focus();
			}
			this.content?.find('.options-box').show();
		});

		this.content.find('.options-box').on('click', (e: MouseEvent) => {
			if (!e.target || !$(e.target).hasClass('options-item')) return;
			let value = $(e.target).attributes('value');
			this.content?.find('input').attributes('placeholder', value);
			this.content?.find('.select-box-input').hide();
			this.content?.find('.select-box-text').text(value).show();
			this.content?.find('.options-item').each((e: any) => {
				$(e).removeClass('options-item-select');
			});
			this.content?.find('.options-box').hide();
			$(e.target).addClass('options-item-select');
			if (onSelect) onSelect(value);
		});
		return this.content;
	}
	renderOptions(
		optionsArr: Array<{ value: string; syntax: string; name: string }>,
		defaultValue: string,
	) {
		let domString = '';
		optionsArr.forEach((e) => {
			domString += `<span class="options-item ${
				defaultValue === e.value ? 'options-item-select ' : ''
			}" name="${e.name}" value="${e.value}"> ${e.value}</span>`;
		});
		return domString;
	}
}
export default codeblockSelect;

==> plugin-codeblock-vue-2.9.8-dev.tgz: package/src/component/select1.ts <==
import {
	$,
	EditorInterface,
	isEngine,
	isHotkey,
	isMobile,
	NodeInterface,
} from '@ctoweb/engine';

type codeblockSelectOptions = {
	modeDatas: Array<{ value: string; syntax: string; name: string }>;
	defaultValue: string;
	onSelect?: (value: string) => void;
};
class codeblockSelect {
	content?: NodeInterface;
	options: codeblockSelectOptions;

	constructor(options: codeblockSelectOptions) {
		this.options = options;
	}
	render() {
		const { modeDatas, defaultValue, onSelect } = this.options;
		this.content = $(`<div class="select-box">
        <div class="select-box-input" style="display:none" > <input type="text"  placeholder="${defaultValue}"></div>
        <div class="select-box-text">${defaultValue}</div>
        <div class="options-box" style="display:none">
             ${this.renderOptions(modeDatas, defaultValue)}
        </div>
    </div>`);
		this.content.find('input').on('input', (e: KeyboardEvent) => {
			if (!e.target) return;
			let value = (e.target as HTMLInputElement).value.toLowerCase();

			if (value) {
				let newModeDatas = modeDatas.filter((e) => {
					return e.value.indexOf(value) > -1;
				});
				this.content
					?.find('.options-box')
					.html(this.renderOptions(newModeDatas, defaultValue));
			}
		});
		this.content.find('input').on('focus', (e: KeyboardEvent) => {
			if (!e.target) return;
			this.content?.find('.options-box').show();
		});
		this.content.find('input').on('blur', (e: KeyboardEvent) => {
			if (!e.target) return;
			setTimeout(() => {
				this.content?.find('.options-box').hide();
			}, 200);
		});
		this.content.find('.select-box-text').on('click', (e: MouseEvent) => {
			if (!e.target || !$(e.target).hasClass('select-box-text')) return;
			$(e.target).hide();
			if (this.content?.find('input').length) {
				this.content?.find('.select-box-input').show();
				(this.content?.find('input')[0] as HTMLInputElement).focus();
			}
			this.content?.find('.options-box').show();
		});

		this.content.find('.options-box').on('click', (e: MouseEvent) => {
			if (!e.target || !$(e.target).hasClass('options-item')) return;
			let value = $(e.target).attributes('value');
			let name = $(e.target).attributes('name');
			this.content?.find('input').attributes('placeholder', name);
			this.content?.find('.select-box-input').hide();
			this.content?.find('.select-box-text').text(name).show();
			this.content?.find('.options-item').each((e: any) => {
				$(e).removeClass('options-item-select');
			});
			this.content?.find('.options-box').hide();
			$(e.target).addClass('options-item-select');
			if (onSelect) onSelect(value);
		});
		return this.content;
	}
	renderOptions(
		optionsArr: Array<{ value: string; syntax: string; name: string }>,
		defaultValue: string,
	) {
		let domString = '';
		optionsArr.forEach((e) => {
			domString += `<span class="options-item ${
				defaultValue === e.value ? 'options-item-select ' : ''
			}" name="${e.name}" value="${e.value}"> ${e.name}</span>`;
		});
		return domString;
	}
}
export default codeblockSelect;
